@@ -1,5 +1,5 @@
 '''
-A python client for accessing NetsBlox
+A python interface for accessing NetsBlox services
 '''
 
 from .editor import * # we import editor into global scope
@@ -8,8 +8,6 @@ from . import turtle  # our wraper around raw turtles
 
 from .common import get_location
 
-from pkg_resources import get_distribution as _get_distribution
-
-__version__ = _get_distribution('netsblox').version
+__version__ = '0.5.0'
 __author__ = 'Devin Jean'
 __credits__ = 'Institute for Software Integrated Systems, Vanderbilt University'
